@@ -61,8 +61,10 @@ class Controller(object):
             func(**kargs)
         else:
             argnames = argspec[0][1:]
-            args = [kargs[name] for name in argnames if kargs.has_key(name)]
-            func(*args)
+            kw = {}
+            for name in argnames:
+                if kargs.has_key(name): kw[name] = kargs[name]
+            func(**kw)
     
     def __call__(self, action, **kargs):
         """Makes our controller a callable to handle requests
